@@ -4,10 +4,11 @@ This is useful to copy data from multiple modules into a single image array.
 This module is not a public API: it's used internally by the classes in
 extra_geom.detectors.
 """
+import sys
 from copy import copy
 from itertools import chain
+
 import numpy as np
-import sys
 
 
 class GridGeometryFragment:
@@ -83,7 +84,12 @@ class SnappedGeometry:
         """Make an output array for self.position_modules()
         """
         shape = extra_shape + self.size_yx
-        return np.full(shape, np.nan, dtype=dtype)
+        if np.issubdtype(dtype, np.floating):
+            return np.full(shape, np.nan, dtype=dtype)
+
+        # zeros() is much faster than full() with 0 - part of the cost is just
+        # deferred until we fill it, but it's probably still advantageous.
+        return np.zeros(shape, dtype=dtype)
 
     def position_modules(self, data, out=None, threadpool=None):
         """Implementation for position_modules_fast
@@ -179,8 +185,8 @@ class SnappedGeometry:
                   **kwargs):
         """Implementation for plot_data_fast
         """
-        from matplotlib.cm import viridis
         import matplotlib.pyplot as plt
+        from matplotlib.cm import viridis
 
         if axis_units not in {'px', 'm'}:
             raise ValueError("axis_units must be 'px' or 'm', not {!r}"
